@@ -5,7 +5,7 @@ use base 'HTML::FormFu::Constraint';
 
 use Scalar::Util qw( looks_like_number );
 
-__PACKAGE__->mk_item_accessors( qw( minimum maximum ) );
+__PACKAGE__->mk_item_accessors(qw( minimum maximum ));
 
 *min = \&minimum;
 *max = \&maximum;
@@ -17,17 +17,23 @@ sub constrain_value {
 
     return if !looks_like_number($value);
 
-    if ( defined ( my $min = $self->minimum ) ) {
+    if ( defined( my $min = $self->minimum ) ) {
         return 0 if $value < $min;
     }
 
-    if ( defined ( my $max = $self->maximum ) ) {
+    if ( defined( my $max = $self->maximum ) ) {
         return 0 if $value > $max;
     }
 
     return 1;
 }
 
+sub _localize_args {
+    my ($self) = @_;
+
+    return $self->min, $self->max;
+}
+
 1;
 
 __END__
