@@ -104,7 +104,13 @@ sub update { shift->create(@_) }
 
 sub create {
     my $self = shift;
-    $self->form->render;
+    if($self->form->submitted) {
+        my $hf = new Hash::Flatten(
+            { ArrayDelimiter => '_', HashDelimiter => '.' } );
+        my $input = $hf->unflatten($self->form->input);
+        $self->default_values( $self->_unfold_repeatable($self->form, $input) );
+    }
+    $self->form->render_data;
     my $obj = $self->_as_object_get( $self->form );
     if ( $self->flatten ) {
         my $hf = new Hash::Flatten(
